##
##  flowd.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2010 OpenPKG Foundation e.V. <http://openpkg.net/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         flowd
Summary:      NetFlow Collector
URL:          http://www.mindrot.org/flowd.html
Vendor:       Damien Miller
Packager:     OpenPKG Foundation e.V.
Distribution: OpenPKG Community
Class:        EVAL
Group:        Auditing
License:      BSD
Version:      0.9.1
Release:      20100110

#   package options
%option       with_fsl   yes
%option       with_perl  yes

#   list of sources
Source0:      http://www.mindrot.org/files/flowd/flowd-%{version}.tar.gz
Source1:      flowd.conf
Source2:      rc.flowd
Source3:      fsl.flowd
Patch0:       flowd.patch

#   build information
Prefix:       %{l_prefix}
BuildRoot:    %{l_buildroot}
BuildPreReq:  OpenPKG, openpkg >= 20060823, byacc, make
PreReq:       OpenPKG, openpkg >= 20060823
%if "%{with_fsl}" == "yes"
BuildPreReq:  fsl
PreReq:       fsl
%endif
%if "%{with_perl}" == "yes"
BuildPreReq:  perl, perl-openpkg
PreReq:       perl
%endif
AutoReq:      no
AutoReqProv:  no

%description
    Flowd is a small, fast and secure NetFlow collector. It understands
    NetFlow protocol 1, 5, 7 and 9 (including IPv6 flows), supports both
    IPv4 and IPv6 transport of flows, is privilege-separated to limit
    the impact of any compromise, supports filtering and tagging of
    flows using a packet filter-like syntax, stores recorded flow data
    in a compact binary format which supports run-time choice over which
    flow fields are stored, and ships with Perl interface for reading
    and parsing the on-disk record format.

%track
    prog flowd = {
        version   = %{version}
        url       = http://www.mindrot.org/flowd.html
        regex     = flowd-(__VER__)\.tar\.gz
    }

%prep
    %setup -q
    %patch -p0

%build
    #   configure program
    %{l_shtool} subst \
        -e 's;_flowd;%{l_rusr};g' \
        flowd.h
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags} %{l_fsl_ldflags}" \
    LIBS="%{l_fsl_libs}" \
    ./configure \
        --prefix=%{l_prefix} \
        --sysconfdir=%{l_prefix}/etc/flowd \
        --localstatedir=%{l_prefix}/var/flowd \
        --disable-gcc-warnings

    #   build program
    %{l_make} %{l_mflags -O}

%if "%{with_perl}" == "yes"
    #   build Perl API
    %{l_prefix}/bin/perl-openpkg prepare
    %{l_prefix}/bin/perl-openpkg -d Flowd configure build
%endif

%install
    #   install program
    rm -rf $RPM_BUILD_ROOT
    %{l_make} %{l_mflags} install DESTDIR=$RPM_BUILD_ROOT

    #   strip down installation
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true

%if "%{with_perl}" == "yes"
    #   install Perl API
    %{l_prefix}/bin/perl-openpkg -d Flowd install
    %{l_prefix}/bin/perl-openpkg -F perl-openpkg-files fixate cleanup
%else
    >perl-openpkg-files
%endif

    #   install default configuration
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE flowd.conf} $RPM_BUILD_ROOT%{l_prefix}/etc/flowd/

    #   install run-command script
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.flowd} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   install OSSP fsl configuration
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/fsl
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE fsl.flowd} $RPM_BUILD_ROOT%{l_prefix}/etc/fsl/

    #   create empty run-time directory
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/var/flowd

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} `cat perl-openpkg-files` \
        '%config %{l_prefix}/etc/fsl/fsl.flowd' \
        '%config %{l_prefix}/etc/flowd/flowd.conf' \
        '%attr(-,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/flowd'

%files -f files

%clean
    rm -rf $RPM_BUILD_ROOT

%post
    #   after upgrade, restart service
    [ $1 -eq 2 ] || exit 0
    eval `%{l_rc} flowd status 2>/dev/null`
    [ ".$flowd_active" = .yes ] && %{l_rc} flowd restart
    exit 0

%preun
    #   before erase, stop service and remove log files
    [ $1 -eq 0 ] || exit 0
    %{l_rc} flowd stop 2>/dev/null
    rm -f $RPM_INSTALL_PREFIX/var/flowd/* >/dev/null 2>&1 || true
    exit 0

